@@ -6,13 +6,11 @@
 #include "index.h"
 
 #if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-#include "ktoolinvocation.h"
+#include <KToolInvocation>
 #endif
 
 #include <QDebug>
-#include <QDir>
 #include <QFileInfo>
-#include <QUrl>
 
 #include <MauiKit/Core/fmh.h>
 #include <MauiKit/FileBrowsing/fmstatic.h>
@@ -27,14 +25,17 @@ void Index::openPaths(const QStringList &paths)
 {
     emit this->openPath(std::accumulate(paths.constBegin(), paths.constEnd(), QStringList(), [](QStringList &list, const QString &path) -> QStringList {
                             const auto url = QUrl::fromUserInput(path);
-                            if (url.isLocalFile()) {
-                                const QFileInfo file(url.toLocalFile());
-                                if (file.isDir())
-                                list << url.toString();
+                            if (url.isLocalFile())
+                            {
+                                if (FMStatic::isDir(url))
+                                {
+                                    list << url.toString();
+                                }
                                 else
-                                list << QUrl::fromLocalFile(file.dir().absolutePath()).toString();
-                            } else
-                            list << url.toString();
+                                {
+                                    list <<  FMStatic::fileDir(url).toString();
+                                }
+                            }
 
                             return list;
                         }));
@@ -43,13 +44,9 @@ void Index::openPaths(const QStringList &paths)
 void Index::openTerminal(const QUrl &url)
 {
 #if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-    if (url.isLocalFile()) {
-        KToolInvocation::invokeTerminal(QString(), url.toLocalFile());
-        return;
-    }
 
-    // Nothing worked, just use $HOME
-    KToolInvocation::invokeTerminal(QString(), QDir::homePath());
+    KToolInvocation::invokeTerminal(QString(), {}, url.isLocalFile() ? url.toLocalFile() : FMStatic::HomePath);
+
 #else
     Q_UNUSED(url)
 #endif
