@@ -3,14 +3,10 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 #include <QCommandLineParser>
+#include <QDate>
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
-#include <QDate>
-
-#include <KAboutData>
-
-#include "index.h"
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -20,33 +16,32 @@
 #endif
 
 #ifdef Q_OS_MACOS
-#include "mauimacos.h"
+#include <MauiKit/Core/mauimacos.h>
 #endif
 
 #include <MauiKit/Core/mauiapp.h>
 
-#if defined Q_OS_MACOS || defined Q_OS_WIN
-#include <KF5/KI18n/KLocalizedString>
-#else
+#include <KAboutData>
 #include <KI18n/KLocalizedString>
-#endif
 
 #include "../index_version.h"
 
 #include "controllers/compressedfile.h"
 #include "controllers/filepreviewer.h"
 #include "controllers/dirinfo.h"
+#include "controllers/folderconfig.h"
+
+#include "index.h"
 
 #include "models/recentfilesmodel.h"
+#include "models/pathlist.h"
 
 #define INDEX_URI "org.maui.index"
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_DisableSessionManager, true);
 
 #ifdef Q_OS_WIN32
     qputenv("QT_MULTIMEDIA_PREFERRED_PLUGINS", "w");
@@ -62,12 +57,12 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon(":/index.png"));
-    MauiApp::instance()->setHandleAccounts(false); // for now index can not handle cloud accounts
+
     MauiApp::instance()->setIconName("qrc:/assets/index.svg");
 
     KLocalizedString::setApplicationDomain("index");
 
-    KAboutData about(QStringLiteral("index"), i18n("Index"), INDEX_VERSION_STRING, i18n("Index allows you to navigate, organize and preview your computer files."),
+    KAboutData about(QStringLiteral("index"), i18n("Index"), INDEX_VERSION_STRING, i18n("Browse, organize and preview your files."),
                      KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
@@ -113,6 +108,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<FilePreviewer>(INDEX_URI, 1, 0, "FilePreviewProvider");
     qmlRegisterType<RecentFilesModel>(INDEX_URI, 1, 0, "RecentFiles");
     qmlRegisterType<DirInfo>(INDEX_URI, 1, 0, "DirInfo");
+    qmlRegisterType<PathList>(INDEX_URI, 1, 0, "PathList");
+//    qmlRegisterType<FolderConfig>(INDEX_URI, 1, 0, "FolderConfig");
 
     engine.load(url);
 
